==> javaee-api-7.0-20150424.131648-31-sources.jar: javax/enterprise/inject/spi/AnnotatedType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.enterprise.inject.spi;

import java.util.Set;

/**
 * Defines alternative meta data for bean class.
 * 
 * @version $Rev: 1427581 $ $Date: 2013-01-01 23:38:17 +0100 (Tue, 01 Jan 2013) $
 */
public interface AnnotatedType<X> extends Annotated
{
    /**
     * Returns class of bean.
     *
     * @return class of bean
     */
    public Class<X> getJavaClass();

    /**
     * Returns set of bean constructors.
     *
     * @return set of constructors
     */
    public Set<AnnotatedConstructor<X>> getConstructors();

    /**
     * Returns set of bean methods.
     *
     * @return set of bean methods
     */
    public Set<AnnotatedMethod<? super X>> getMethods();

    /**
     * Returns set of bean fields.
     *
     * @return set of bean fields.
     */
    public Set<AnnotatedField<? super X>> getFields();
}

==> javaee-api-8.0-1-sources.jar: javax/enterprise/inject/spi/AnnotatedType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.enterprise.inject.spi;

import java.lang.annotation.Annotation;
import java.util.Arrays;
import java.util.LinkedHashSet;
import java.util.Set;

/**
 * Defines alternative meta data for bean class.
 * 
 * @version $Rev: 1796175 $ $Date: 2017-05-25 12:54:22 -0400 (Thu, 25 May 2017) $
 */
public interface AnnotatedType<X> extends Annotated
{
    /**
     * Returns class of bean.
     *
     * @return class of bean
     */
    Class<X> getJavaClass();

    /**
     * Returns set of bean constructors.
     *
     * @return set of constructors
     */
    Set<AnnotatedConstructor<X>> getConstructors();

    /**
     * Returns set of bean methods.
     *
     * @return set of bean methods
     */
    Set<AnnotatedMethod<? super X>> getMethods();

    /**
     * Returns set of bean fields.
     *
     * @return set of bean fields.
     */
    Set<AnnotatedField<? super X>> getFields();

    @Override
    default <T extends Annotation> Set<T> getAnnotations(Class<T> annotationType)
    {
        return new LinkedHashSet<>(Arrays.asList(getJavaClass().getAnnotationsByType(annotationType)));
    }

}
